==> monaco-vscode-debug-service-override-2.1.0.tgz: package/debug.js <==
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug';
import { DebugService } from './vscode/src/vs/workbench/contrib/debug/browser/debugService.js';
import { LanguageFeaturesService } from 'vscode/vscode/vs/editor/common/services/languageFeaturesService';
import { ILanguageFeaturesService } from 'vscode/vscode/vs/editor/common/services/languageFeatures';
import { ConfigurationResolverService } from './vscode/src/vs/workbench/services/configurationResolver/browser/configurationResolverService.js';
import { IConfigurationResolverService } from 'vscode/vscode/vs/workbench/services/configurationResolver/common/configurationResolver';
import { IExtensionHostDebugService } from 'vscode/vscode/vs/platform/debug/common/extensionHostDebug';
import { BrowserExtensionHostDebugService } from './vscode/src/vs/workbench/contrib/debug/browser/extensionHostDebugService.js';
import { IDebugVisualizerService, DebugVisualizerService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugVisualizers';
import getServiceOverride$1 from '@codingame/monaco-vscode-layout-service-override';
import './vscode/src/vs/workbench/contrib/debug/browser/debug.contribution.js';

const original = DebugService.prototype['showError'];
DebugService.prototype['showError'] = function (message, errorActions) {
    return original.call(this, message, errorActions, false);
};
function getServiceOverride() {
    return {
        ...getServiceOverride$1(),
        [( ILanguageFeaturesService.toString())]: new SyncDescriptor(LanguageFeaturesService, [], true),
        [( IDebugService.toString())]: new SyncDescriptor(DebugService, [], true),
        [( IConfigurationResolverService.toString())]: new SyncDescriptor(ConfigurationResolverService, [], true),
        [( IExtensionHostDebugService.toString())]: new SyncDescriptor(BrowserExtensionHostDebugService, [], true),
        [( IDebugVisualizerService.toString())]: new SyncDescriptor(DebugVisualizerService, [], true)
    };
}

export { getServiceOverride as default };

==> monaco-vscode-debug-service-override-4.1.0.tgz: package/debug.js <==
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug';
import { DebugService } from 'vscode/vscode/vs/workbench/contrib/debug/browser/debugService';
import { LanguageFeaturesService } from 'vscode/vscode/vs/editor/common/services/languageFeaturesService';
import { ILanguageFeaturesService } from 'vscode/vscode/vs/editor/common/services/languageFeatures';
import { ConfigurationResolverService } from 'vscode/vscode/vs/workbench/services/configurationResolver/browser/configurationResolverService';
import { IConfigurationResolverService } from 'vscode/vscode/vs/workbench/services/configurationResolver/common/configurationResolver';
import { IExtensionHostDebugService } from 'vscode/vscode/vs/platform/debug/common/extensionHostDebug';
import { BrowserExtensionHostDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/browser/extensionHostDebugService';
import { IDebugVisualizerService, DebugVisualizerService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugVisualizers';
import './tools/debugAssets.js';
import 'vscode/vscode/vs/workbench/contrib/debug/browser/debug.contribution';

const original = DebugService.prototype['showError'];
DebugService.prototype['showError'] = function (message, errorActions) {
    return original.call(this, message, errorActions, false);
};
function getServiceOverride() {
    return {
        [( ILanguageFeaturesService.toString())]: new SyncDescriptor(LanguageFeaturesService, [], true),
        [( IDebugService.toString())]: new SyncDescriptor(DebugService, [], true),
        [( IConfigurationResolverService.toString())]: new SyncDescriptor(ConfigurationResolverService, [], true),
        [( IExtensionHostDebugService.toString())]: new SyncDescriptor(BrowserExtensionHostDebugService, [], true),
        [( IDebugVisualizerService.toString())]: new SyncDescriptor(DebugVisualizerService, [], true)
    };
}

export { getServiceOverride as default };
